@@ -311,7 +311,7 @@ EvdevWheelEmuPreInit(InputInfoPtr pInfo)
 }
 
 #ifdef HAVE_PROPERTIES
-int
+static int
 EvdevWheelEmuSetProperty(DeviceIntPtr dev, Atom atom, XIPropertyValuePtr val,
                          BOOL checkonly)
 {
@@ -350,11 +350,13 @@ EvdevWheelEmuSetProperty(DeviceIntPtr dev, Atom atom, XIPropertyValuePtr val,
     }
     else if (atom == prop_wheel_button)
     {
-        int bt = *((CARD8*)val->data);
+        int bt;
 
         if (val->format != 8 || val->size != 1 || val->type != XA_INTEGER)
             return BadMatch;
 
+        bt = *((CARD8*)val->data);
+
         if (bt < 0 || bt >= EVDEV_MAXBUTTONS)
             return BadValue;
 
@@ -374,11 +376,13 @@ EvdevWheelEmuSetProperty(DeviceIntPtr dev, Atom atom, XIPropertyValuePtr val,
         }
     } else if (atom == prop_wheel_inertia)
     {
-        int inertia = *((CARD16*)val->data);
+        int inertia;
 
         if (val->format != 16 || val->size != 1 || val->type != XA_INTEGER)
             return BadMatch;
 
+        inertia = *((CARD16*)val->data);
+
         if (inertia < 0)
             return BadValue;
 
@@ -386,11 +390,13 @@ EvdevWheelEmuSetProperty(DeviceIntPtr dev, Atom atom, XIPropertyValuePtr val,
             pEvdev->emulateWheel.inertia = inertia;
     } else if (atom == prop_wheel_timeout)
     {
-        int timeout = *((CARD16*)val->data);
+        int timeout;
 
         if (val->format != 16 || val->size != 1 || val->type != XA_INTEGER)
             return BadMatch;
 
+        timeout = *((CARD16*)val->data);
+
         if (timeout < 0)
             return BadValue;
 
